#!/bin/sh
# Function: Removes existing NL1 architect developer folders in $RSA_HOME
# and replaces them with updated ones.
# Generally this upgrade script starts executing from
# $RSA_HOME/updater/workspace/proxies/eclipse/features/updater.zip.6001/temp
# Expects the home location of RSA and RWD (for runtimes/ directory) to be
# passed in as arguments.


RSA_HOME=$1
RWD_HOME=$2
LOG_FILE="/tmp/rsa.rup.nl1.update.log"
RSA_CONFIG="rup_rsa_configuration.nl1.zip"
ROLLBAK_DIR="../rup.rsa.configuration.rollback.nl1"

### Main Routine ###
PWD=`pwd`
echo "Starting RSA RUP NL1 update in $PWD" > $LOG_FILE

# Prep rollback environment
/bin/cp -f rup_rollbak_4_rsa_linux.nl1.sh ../

# Check for existence of NL1 configurations
if [ -d $RSA_HOME/RUP\ Configuration/architect.fr ] || 
   [ -d $RSA_HOME/RUP\ Configuration/architect.ja ] || 
   [ -d $RSA_HOME/RUP\ Configuration/architect.ko ] || 
   [ -d $RSA_HOME/RUP\ Configuration/architect.pt_BR ] || 
   [ -d $RSA_HOME/RUP\ Configuration/architect.zh_CN ]; then
        NL1=1
fi

if [ $NL1 ]; then                                                                                
  # Prep rollback configuration environment
  # Create $ROLLBAK_DIR only if NL1 configurations are present
  /bin/mkdir $ROLLBAK_DIR

  # Backup existing applicaiton developer folders for future rollback
  /bin/mv -f $RSA_HOME/RUP\ Configuration/architect.* $ROLLBAK_DIR/
  echo "Backed up existing NL1 RSA configurations." >> $LOG_FILE
                                                                                
  # Test for existence of jar utility and execute them
  if [ -x $RWD_HOME/runtimes/base_v6_stub/java/bin/jar ]; then
    $RWD_HOME/runtimes/base_v6_stub/java/bin/jar xf $RSA_CONFIG
  elif [ -x $RWD_HOME/runtimes/base_v51_stub/java/bin/jar ]; then
    $RWD_HOME/runtimes/base_v51_stub/java/bin/jar xf $RSA_CONFIG
  elif [ -x $RWD_HOME/runtimes/base_v5_stub/java/bin/jar ]; then
    $RWD_HOME/runtimes/base_v5_stub/java/bin/jar xf $RSA_CONFIG
  else
    echo "Cannot find executable jar file(s) in $RWD_HOME/runtimes" >> $LOG_FILE
    echo "Update of RUP NL1 RSA configurations failed!" >> $LOG_FILE
    exit 1
  fi
  /bin/mv -f RUP\ Configuration/architect* $RSA_HOME/RUP\ Configuration/
  /bin/rm -rf RUP\ Configuration/
  echo "Update of RUP NL1 RSA  configurations succeeded." >> $LOG_FILE
else
  echo "Update not performed because no NL1 RSA configurations were found in $RSA_HOME/RUP Configuration." >> $LOG_FILE

fi
